@@ -128,7 +128,7 @@ public:
     int heightForWidth(int w) const override
     {
         int height = 0;
-        Q_FOREACH(Row* row, mRows) {
+        for (Row* row : qAsConst(mRows)) {
              height += row->heightForWidth(w);
         }
         return height;
@@ -158,7 +158,7 @@ public:
 
     void finishAddRows()
     {
-        qSort(mRows.begin(), mRows.end(), KeyValueWidget::rowsLessThan);
+        std::sort(mRows.begin(), mRows.end(), KeyValueWidget::rowsLessThan);
         updateGeometry();
     }
 
@@ -169,7 +169,7 @@ public:
         // from one image to another
         int rowY = 0;
         const int labelWidth = width();
-        Q_FOREACH(Row* row, mRows) {
+        for (Row* row : qAsConst(mRows)) {
             rowY = row->setLabelGeometries(rowY, labelWidth);
         }
     }
@@ -229,7 +229,7 @@ struct InfoContextManagerItemPrivate
 
         QWidget* content = new QWidget;
         QVBoxLayout* layout = new QVBoxLayout(content);
-        layout->setMargin(2);
+        layout->setContentsMargins(2, 2, 2, 2);
         layout->setSpacing(2);
         layout->addWidget(mKeyValueWidget);
         layout->addWidget(moreLabel);
@@ -285,7 +285,7 @@ void InfoContextManagerItem::updateSideBarContent()
     LOG("updateSideBarContent: really updating");
 
     KFileItemList itemList = contextManager()->selectedFileItemList();
-    if (itemList.count() == 0) {
+    if (itemList.isEmpty()) {
         d->forgetCurrentDocument();
         d->mOneFileWidget->hide();
         d->mMultipleFilesLabel->hide();
@@ -321,7 +321,7 @@ void InfoContextManagerItem::fillMultipleItemsGroup(const KFileItemList& itemLis
     d->forgetCurrentDocument();
 
     int folderCount = 0, fileCount = 0;
-    Q_FOREACH(const KFileItem & item, itemList) {
+    for (const KFileItem & item : itemList) {
         if (item.isDir()) {
             folderCount++;
         } else {
@@ -349,7 +349,8 @@ void InfoContextManagerItem::updateOneFileInfo()
 
     ImageMetaInfoModel* metaInfoModel = d->mDocument->metaInfo();
     d->mKeyValueWidget->clear();
-    Q_FOREACH(const QString & key, GwenviewConfig::preferredMetaInfoKeyList()) {
+    const QStringList preferredMetaInfoKeyList = GwenviewConfig::preferredMetaInfoKeyList();
+    for (const QString & key : preferredMetaInfoKeyList) {
         QString label;
         QString value;
         metaInfoModel->getInfoForKey(key, &label, &value);
