@@ -30,9 +30,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGraphicsLinearLayout>
 #include <QGraphicsProxyWidget>
 #include <QMouseEvent>
-#include <QTime>
+#include <QElapsedTimer>
 #include <QDebug>
 #include <QIcon>
+#include <QTime>
 
 // KDE
 
@@ -56,7 +57,7 @@ struct VideoViewAdapterPrivate
     GraphicsWidgetFloater* mFloater;
 
     HudSlider* mSeekSlider;
-    QTime mLastSeekSliderActionTime;
+    QElapsedTimer mLastSeekSliderActionTime;
 
     QAction* mPlayPauseAction;
     QAction* mMuteAction;
