@@ -401,7 +401,7 @@ bool FITSData::checkDebayer()
         return false;
     }
     QString pattern(bayerPattern);
-    pattern = pattern.remove("'").trimmed();
+    pattern = pattern.remove('\'').trimmed();
 
     if (pattern == "RGGB") {
         debayerParams.filter = DC1394_COLOR_FILTER_RGGB;
